package cafetrans;

%cafetrans::translation = (

"id"                       => "fr",
"Action"                   => "Action",
"address"                  => "Adresse",
"Address Group"            => "Liste de diffusion",
"Address Id"               => "Id de l'adresse",
"Address label"            => "Libelle de l'adresse",
"addressl"                 => "Liste des Adresses",
"Address Line 1"           => "Ligne 1",
"Address Line 2"           => "Ligne 2",
"Address Status"           => "Etat",
"Address Type"             => "Type",
"Administrator mail"       => "Email de l'administrateur",
"After connect SubFlow"    => "Aprs connexion",
"After prepare main query" => "Aps prpare",
"After read message"       => "Aprs lecture enreg",
"After start transformation" => "Aprs transformation",
"After the flow is finished" => "Aprs fin flux",
"After the flow is started" => "Aprs dbut flux",
"After write message"      => "Aprs criture",
"Aliphe : Data Quality Assessment Company" => "Aliphe : l'Assurance qualit pour vos donnes",
"allobjects"               => "Tous les objects",
"Alter Query"              => "Alter",
"Archival frequency"       => "Frquence d'archivage",
"Archive Connector Id"     => "Connecteur d'archivage",
"Atome"                    => "Atome",
"Attrdef Id"               => "Id de l'attribut",
"Attrdef label"            => "Libell de l'attribut",
"attrdefl"                 => "Les attributs",
"Attribut default"         => "Valeur par dfaut",
"Attribute Data Type"      => "Type de valeur",
"Attribute for Objects of Type" => "Pour le sobjets de type",
"Attribute Id"             => "Id de l'attribut",
"Attribute label"          => "Libelle de l'attribut",
"Attributes List"          => "List des Attributs",
"Attribute Value"          => "Valeur",
"Back"                     => "Retour  la liste",
"Before connect SubFlow"   => "Avant connexion",
"Before prepare main query" => "Avant Prepare",
"Before read message"      => "Avant Lecture",
"Before start transformations" => "Avant transformation",
"Before the flow is finished" => "Avant fin du flux",
"Before the flow is started" => "Avant dbut du flux",
"Before write message"     => "Avant ecriture",
"Blowfish Alogorithm"      => "Algorithme Blowfish",
"Bottom"                   => "Fin",
"Buffered?"                => "Historiser ?",
"bufferedflow"             => "Flux indirect (historis)",
"Buffered sub flows"       => "Sous-flux indirects",
"Cafeterra - a product from" => "Cafeterra - un produit de ",
"Cafeterra the FREE EAI"   => "Cafeterra l'EAI LIBRE",
"cafusrl"                  => "Utilisateurs Cafeterra",
"Caller page"              => "Page appelante",
"Change"                   => "Changer",
"Check Files Permissions"  => "Vrifier les permissions des fichiers",
"Check Perl Modules"       => "Vrifier les modules Perl",
"choose2"                  => "== Choisir une option ==",
"choose"                   => "====== Choisir une option ======",
"choosemenu"               => "====== Choisir un menu ======",
"Choose status"            => "= Choisir un statut =",
"choosesubmenu"            => "====== Choisir un sous menu ======",
"Comments"                 => "Commentaires",
"commitinterv"             => "Valider tous les",
"Committing condition"     => "Valider les transactions",
"Compression"              => "Compression ?",
"Conainer Id"              => "Id du conteneur",
"config"                   => "Configuration",
"Confirm Drop"             => "Confirmer la suppression",
"Connect"                  => "Connexion",
"Connector"                => "Connecteur",
"Connector Id"             => "Id du connecteur",
"Connector Id Label"       => "Id/Libell du Connecteur",
"Connector info"           => "Info sur le connecteur",
"Connector info"           => "Info sur le connecteur",
"Connector Label"          => "Nom local du connecteur",
"connectorl"               => "Connecteurs",
"Connector name"           => "Nom externe du connecteur",
"Connector object"         => "Connecteur",
"Connector status"         => "Etat du connecteur",
"Container"                => "Conteneur",
"Container Id"             => "Id du conteneur",
"Container info"           => "Info sur le conteneur",
"Container label"          => "Libell du conteneur",
"containerl"               => "Conteneurs",
"Container name"           => "Nom du conteneur",
"Container object"         => "Conteneur",
"Container pattern"        => "Pattern recherche conteneur",
"Container pattern"        => "Pattern recherche conteneur",
"Container Remarks"        => "Remarques",
"Containers"               => "Conteneurs",
"Container status"         => "Etat du conteneur",
"Context Connector Id"     => "Connecteur Base de donnes",
"Context Id"               => "Id context",
"Context label"            => "Libell context",
"contextl"                 => "Contextes",
"Copy"                     => "Dupliquer",
"Create container if not exist" => "Crer le conteneur si inexistant",
"Create copy"              => "Crer la copie",
"Create"                   => "Crer",
"Created by"               => "Cr par",
"Created on"               => "Cr le",
"Create Query"             => "Create",
"Crontab style"            => "Style crontab",
"Current function"         => "Fonction courante",
"daemon"                   => "demon (unix)",
"Dataformat"               => "Format de donne",
"Dataformat Id"            => "Id du format de donne",
"Datalength"               => "Longueur",
"Datascale"                => "Chiffre apr la virgule",
"Datatype"                 => "Type de donne",
"Datatype Id"              => "Id de type de donne",
"datatypel"                => "Types de donnes",
"Date"                     => "Date de dernier dploiment",
"days"                     => "jours",
"Doc Day(s)"               => "Jour(s)",
"DBI DSN"                  => "Nom, DBI, de source de donnes",
"Deep Copy"                => "Copie profonde",
"Default"                  => "Par dfaut",
"Default (stop)"           => "Par dfaut (stop)",
"Default value"            => "Valeur par dfaut",
"Delete"                   => "Delete",
"Deleted status"           => "Supprime",
"Delete Query"             => "Requete Delete",
"Del-Ins"                  => "Delete puis Insert",
"dependant"                => "Dependant",
"Deploy"                   => "Dployer",
"Deploy selected objects"  => "Dployer les objects slectionns",
"Deployed Objects Count"   => "Nombre d'objets dploys",
"DES Alogorithm"           => "Algorithme DES",
"Error's Detail"           => "Dtails de l'erreur",
"Message's Detail"         => "Dtails du message",
"Disabled Status"          => "Dsactiv",
"Doc Attribute Id"         => "Id de l'attribut",
"Doc Attribute Label"      => "Libelle de l'attribut",
"Doc Attributes List"      => "Liste des attributs",
"Doc Attribute Value"      => "Valeur de l'attribut",
"Doc Buffered?"            => "Historis?",
"Doc Comments"             => "Commentaire",
"Doc Compression"          => "Mode de Compression",
"Doc Conainer Id"          => "Id conteneur",
"Doc Connector External name" => "Nom externe",
"Doc Connector Id"         => "Id connecteur",
"Doc Connector Label"      => "Libelle du connecteur",
"Doc Container Id"         => "Id conteneur",
"Doc Container Label"      => "Libelle du conteneur",
"Doc Container Name"       => "Nom du Conteneuer",
"Doc Datatype"             => "Type de donne",
"Doc DBI DSN"              => "Nom, DBI, de source de donnes",
"Doc Default Value"        => "Valeur par dfaut",
"Doc Driver Name"          => "Nom du pilote",
"Doc Encryption Key (Phase 1)" => "Cl de cryptage (Phase 1)",
"Doc Encryption Key (Phase 2)" => "Cl de cryptage (Phase 2)",
"Doc Encryption Method (Phase 1)" => "Mthode de cryptage (Phase 1)",
"Doc Encryption Method (Phase 2)" => "Mthode de cryptage (Phase 2)",
"Doc Env. Variable Name"   => "Nom de la variable Name",
"Doc Env. Variables List"  => "Liste des variables",
"Doc Env. Variable Type"   => "Type de la variable",
"Doc Env. Variable Value"  => "Valeur de la variable",
"Doc Event Id"             => "Id vnement",
"Doc Events"               => "Les vnements",
"Doc Expire Delay"         => "Dlai d'expiration",
"Doc External Name"        => "Nom Externe",
"Doc External Schema"      => "Schema externe",
"Doc External Type"        => "Type external",
"Doc Field Externalname"   => "Nom externe",
"Doc Field Label"          => "Libelle du champ",
"Doc Flow Label"           => "Libelle du flux",
"Doc Flow Name"            => "Nom du flux",
"Doc Flow Status"          => "Etat du flux",
"Doc Flow Type"            => "Type de flux",
"Doc Formula"              => "Formule",
"Doc Gen Or Wait"          => "Type vnement",
"Doc Host Address"         => "Adresse du host",
"Doc Host External name"   => "Nom du host",
"Doc Host Label"           => "Libelle du host",
"Doc Host Status"          => "Etat du host",
"Doc Field Id"             => "Id champs",
"Doc Incom Relationship"   => "Flux entrants",
"Doc Keep Alive"           => "Garder la connexion",
"Doc Key Pos"              => "Pos dans la cl",
"Doc Lang"                 => "Langage",
"Doc Length"               => "Longueur",
"Doc Mapping"              => "Mapping",
"Doc Modified By"          => "Modifi par",
"Doc Modified On"          => "Modifi le",
"Doc Null"                 => "Nullable",
"Doc Object ID"            => "Id objet",
"Doc Object Status"        => "Etat objet",
"Doc On Error"             => "Si erreur",
"Doc On Success"           => "Si succs",
"Doc Order"                => "Ordre",
"Doc Parse Status"         => "Valide ?",
"Doc Port Number"          => "Port",
"Doc Pos"                  => "Position",
"Doc Preferred Flow Direction" => "Dir de flux",
"Doc Programs And Scripts" => "Programmes et scripts",
"Doc Protocol Name"        => "Nom du protocol",
"Doc Proxy Id"             => "Id du Proxy",
"Doc Proxy Label"          => "Libell du proxy",
"Doc Proxy Status"         => "Etat",
"Doc Raise Mail Alert"     => "Envoyer 1 mail ?",
"Doc Scale 2"              => "Scale",
"Doc Script Id"            => "Id du script",
"Doc Script Label"         => "Libell du script",
"Doc Script Language"      => "Language",
"Doc Script Text"          => "Texte du script",
"Doc Script Type"          => "Type de script",
"Doc Server Id"            => "Id du serveur",
"Doc Source Field"         => "Champ source",
"Doc Status"               => "Etat",
"Doc Step"                 => "Etape",
"Doc Subflow Dir"          => "Direction",
"Doc Subflow Id"           => "Id du sous flux",
"Doc Subflow Label"        => "Libell du demi flux Label",
"Doc Subflow Method"       => "Mthode",
"Doc Subflow Name"         => "Nom du demi-flux",
"Doc Sublow Order"         => "Ordre",
"Doc Target Field"         => "Champ dest.",
"Document"                 => "Documentation imprimable",
"Doc Used For"             => "Utils pour",
"Doc Use Internal Rollback Space" => "Utilser Rollback interne",
"Doc User Id"              => "Id utilisateur",
"Doc User Login"           => "Login utilisateur",
"Doc Users Id"             => "Id utilisateur",
"Doc Users Password"       => "Mot de passe",
"Driver Error Code"        => "Code Erreur du pilote",
"Driver Id"                => "Id du pilote",
"Driver label"             => "Libell du pilote",
"driverl"                  => "Pilotes",
"Driver Name"              => "Nom de pilote",
"Driver"                   => "Pilote",
"Drop"                     => "Supprimer",
"drop Query"               => "Requete Drop",
"Edit"                     => "Editer",
"Edit Vars"                => "Editer les variables du flux",
"Email Address"            => "Adresse E-mail",
"Enabled Status"           => "Activ",
"Encryption key (Phase 1)" => "Cl de cryptage (Phase 1)",
"Encryption key (Phase 2)" => "Cl de cryptage (Phase 2)",
"Encryption method (Phase 1)" => "Mthode de cryptage (Phase 1)",
"Encryption method (Phase 2)" => "Mthode de cryptage (Phase 2)",
"End of Attributes List"   => "Fin de la liste des attributs",
"Env. var"                 => "Variable d'environnement",
"Env. Variable Name"       => "Nom de la variable",
"Env. Variables List"      => "Liste des variables",
"Env. Variable Type"       => "Type de la vairiable",
"Env. Variable Value"      => "Valuer de la vairiable",
"Error Code"               => "Code erreur",
"Error Context"            => "Context de l'erreur",
"Error Date"               => "Date",
"Error File"               => "Fichier erreurs (stderr)",
"Error Id"                 => "Id erreur",
"Errors handler"           => "Gestionnaire d'erreur",
"Errors occured during this transactoin" => "Erreurs survenues lors de cette transaction",
"Error Text"               => "Texte de l'erreur",
"Event Generated by"       => "Evnements gnr par",
"Event Id"                 => "Id de l'vnement",
"eventl"                   => "Evnements",
"Event Name"               => "Nom de l'vnnement",
"Events"                   => "Evnements ",
"Event Type"               => "Type d'vnnement",
"Every 1000 messages"      => "Tous les 1000 messages",
"Every 100 messages"       => "Tous les 100 messages",
"Every 10 messages"        => "Tous les 10 messages",
"Every message"            => "Chaque message",
"Expire Delay"             => "Dlai d'expiration",
"External name"            => "Nom externe",
"External Schema"          => "Schema (propritaire)",
"External Type"            => "Type natif",
"extobj"                   => "Objects Externes",
"Fax Number"               => "Fax",
"Field External Name"      => "Nom externe",
"Field extrnalname"        => "Nom externe",
"Field"                    => "Champ",
"Field Id"                 => "Id champ",
"Field label"              => "Libell champ",
"fieldl"                   => "Champs",
"Field Name"               => "Nom du champ",
"Field object"             => "Champ",
"Field order"              => "Ordre",
"Field position"           => "Position",
"Field position in key"    => "Position dans la cl",
"Fields contents"          => "Contenu des champs",
"Fields"                   => "Champs",
"Fields label"             => "Libell des champs",
"Field specific transformation" => "Transformation de champs",
"Field status"             => "Etat",
"Five Days"                => "Cinq jours",
"flowdef"                  => "Definition des Flux",
"Flow"                     => "Flux",
"Flow Id"                  => "Id du flux",
"Flow Label"               => "Libll du flux",
"flowl"                    => "Definition des Flux",
"Flow name"                => "Nom du flux",
"Flow object"              => "Flux",
"Flow status"              => "Etat",
"Flow Type"                => "Type de flux",
"Formula"                  => "Formule",
"Four Days"                => "Quatre jours",
"From Date"                => "Depuis",
"FTP Connector Id"         => "Id du connecteur FTP",
"Full"                     => "Full",
"Generated events"         => "Evnements gnrs",
"Generate/Wait"            => "Gnrer/Attendre",
"Global Commit"            => "Commit Global",
"Global"                   => "Global",
"group"                    => "Groupe d'adresses",
"Group Id"                 => "Id du groupe",
"Group label"              => "Libll du groupe",
"gzip (require Compress::Zlib)" => "gzip (require Compress::Zlib)",
"Halte"                    => "Arrt",
"Help"                     => "Aide",
"home"                     => "Accueil",
"Host address"             => "Addresse du host",
"Host label"               => "Libell du host",
"Host name"                => "Nom (local) du host",
"Hostsallow"               => "Hosts autoriss",
"Hostsdeny"                => "Hosts non autoriss",
"Host status"              => "Etat",
"IDEA Alogorithm"          => "Algorithm IDEA",
"Subflow Id"               => "Id demi-flux",
"Script Id"                => "Id script",
"Container Id"             => "Id conteneur",
"Connector Id"             => "Id connecteur",
"Import Containers"        => "Importer Conteneurs",
"Import"                   => "Importer",
"Import In new Container"  => "Importer comme nouveau",
"Import Selected"          => "Importer les objets slectionns",
"Import Update existing Container" => "Mettre  jour pendant l'import",
"incom and outgo"          => "Entrant et sortant",
"incom"                    => "Entrant",
"Incominf flows relationship" => "Relation entre les flux entrants",
"Incoming and outgoing flows" => "Entrant et sortant",
"Incoming flows"           => "Flux entrant(s)",
"Incoming flows only"      => "Entrant seulement",
"Incom Message Id"         => "Id du message entrant",
"Incom Message"            => "Message Entrant",
"Incomming flow"           => "Flux entrant",
"Incom relationship"       => "Flux Entrant",
"incomrel"                 => "Flux Entrant",
"independant"              => "Indpendant",
"Insert"                   => "Insert",
"Insert Query"             => "Requete INSERT",
"install basedir"          => "Rpertoire des programmes Cafeterra",
"install cgialias"         => "Alias CGI pour ce contexte",
"install contextdbname"    => "Nom de la base de donnes",
"install contextdsn"       => "Nom, DBI, de source de donnes",
"install contextid"        => "Identifiant du contexte",
"install contextlabel"     => "Libell du contexte",
"install contextpwd"       => "Mot de passe",
"install contexttype"      => "Type de contexte",
"install contextuser"      => "Nom de l'utilisateur base de donnes",
"install createdb"         => "Crer la base de donnes",
"install createdbuser"     => "Crer l'utilisateur ?",
"install design"           => "Contexte de dveloppement",
"install docalias"         => "Alias DIR  pour ce contexte",
"install dropobjects"      => "Supprimer les tables avant de les crer ?",
"install httpdpath"        => "Chemin pour le fichier httpd.conf",
"install ignoredataerr"    => "Ignorer les erreurs lors de l'initialisation des dones",
"install ignoreobjerr"     => "Ignorer les erreurs lors de la cration des tables",
"install printerrors"      => "Afficher les erreurs ?",
"install masterdsn"        => "Nom, DBI, de la source de donnes Maitre (Pg)",
"install masterpwd"        => "Mot de passe maitre",
"install masteruser"       => "Utilisateur BdD maitre",
"Install"                  => "Installer",
"install production"       => "Contexte de production ou de test",
"Ins-Upd"                  => "Insert puis Update",
"IP Address"               => "Adresse IP",
"Is a local field"         => "Champ de calcul ?",
"Is Master"                => "Est maitre ?",
"Keep Alive?"              => "Garder la connexion ?",
"Keep Alive"               => "Garder la connexion",
"key pos"                  => "Pos/Cl",
"Last Acces"               => "Dernier acces",
"Last Exec Time"           => "Drnire excution",
"Last modified"            => "Date dernire modification",
"Last Query"               => "Dernire requete",
"Launch Monitor"           => "Lancer le Moniteur",
"Launch"                   => "Lancer demon",
"Launch once"              => "Executer une fois",
"Stop Monitor"             => "Arrter le Moniteur",
"length"                   => "Longueur",
"List"                     => "L",
"Main Menu"                => "MENU PRINCIPALE",
"Mapping"                  => "Mapping",
"Master connector"         => "Connecteur maitre",
"Master Id"                => "Id du maitre",
"Member of Group Id"       => "Membre du groupe",
"Memebr Status"            => "Etat du membre",
"merrorl"                  => "Suivie des Erreurs de Flux",
"Mesage Data"              => "Donnes du message",
"Mesage Date"              => "Date du message",
"Message Id"               => "Id du message",
"Message Status"           => "Etat du message",
"Method"                   => "Methode",
"mflowl"                   => "Surveillance des flux",
"Mobile Number"            => "Tlphone mobile",
"Modified by"              => "Modifi par",
"Modified on"              => "Modifi par",
"Modified on"              => "Modifi le",
"Modify"                   => "Appliquer les modifs",
"monitoring"               => "Surveillance",
"Local name"               => "Nom local",
"New"                      => "Nouveau",
"Next Exec Time"           => "Prochaine execution",
"Next"                     => "Suivants",
"nochoice"                 => "================================",
"No compression"           => "Pas de compression",
"no"                       => "Non",
"Normal"                   => "Normal",
"Not running status"       => "N'est pas lanc",
"null"                     => "Null",
"Number"                   => "Nombre",
"Object id"                => "Id de l'object",
"Object Label"             => "Libell de l'objet",
"Object Name"              => "Nom de l'objet",
"Object Owner"             => "Propritaire",
"Objects Name"             => "Noms des objets",
"Objects Status"           => "Etats des objets",
"Object Status"            => "Etat de l'objet",
"Objects Type"             => "Types des objets",
"Object Type"              => "Type d'objets",
"Offline status"           => "Inactif",
"Offline Status"           => "Inactif",
"One Day"                  => "Un jour",
"On Error"                 => "Si erreur",
"Online status"            => "Actif",
"Online Status"            => "Actif",
"On success"               => "Si succs",
"Order"                    => "Ordre",
"Other connectors"         => "Autres connecteurs",
"Other containers"         => "Autres conteneurs",
"Other script"             => "Autres scripts",
"Outgoing flow"            => "Flux sortant",
"Outgoing flows"           => "Flux sortants",
"Outgoing flows only"      => "Flux sortant seulement",
"outgo"                    => "Sortant",
"Owner Id"                 => "Id du propritaire",
"Owner"                    => "Propritaire",
"Owner Type"               => "Type de propritaire",
"Parsed text"              => "Text analys",
"Parse status"             => "Etat de l'analyse",
"Paused status"            => "Pause",
"Perl"                     => "Perl",
"Perl scripts"             => "Scripts Perl",
"Perl Type"                => "Type Perl",
"Perl Value"               => "Valeur Perl",
"POP3 Connector Id"        => "Id du connecteur POP3",
"Port Number"              => "Numro du port",
"pos"                      => "Position",
"Postal City"              => "Ville",
"Postal Code"              => "Code Postal",
"Preferred Flow Direction" => "Direction de flux privilgie",
"Previous"                 => "Prcdents",
"Printer Address"          => "Imprimante",
"Process Id"               => "Id du processus",
"Program dir"              => "Rpertoire des programmes",
"Programs and scripts"     => "Programmes et scripts",
"Programs"                 => "Programmes",
"Protocol Id"              => "Id du protocol",
"Protocol label"           => "Libell du protocol",
"protocoll"                => "Protocols",
"Protocol Name"            => "Nom du protocol",
"proxycafl"                => "Les proxy cafeterra",
"Proxy Id"                 => "Id du proxy",
"Proxy Label"              => "Libll du proxy",
"Proxy name"               => "Nom du proxy",
"Proxy Status"             => "Etat du proxy",
"Raised by"                => "Gnr par",
"Raise mail alert"         => "Envoi du mail",
"Refresh Interval"         => "Interval de raffraichissement",
"Remarks"                  => "Remarques",
"Reset"                    => "Reinitialiser",
"Running status"           => "En cours d'execution",
"Runtime Status"           => "En cours d'execution",
"scale 2"                  => "Scale",
"Scheduled hours"          => "Heures",
"Scheduled mdays"          => "Jours du mois",
"Scheduled minutes"        => "Minutes",
"Scheduled months"         => "Mois",
"Scheduled wdays"          => "Jours de semaine",
"Schedule Id"              => "Id du planning",
"Schedule label"           => "Libll du planning",
"schedulel"                => "Planification de l'execution des flux",
"Scheduler Id"             => "Id du planning",
"Scheduler label"          => "Libll du planning",
"Scheduler mode"           => "Mode d'execution",
"Scheduler status"         => "Etat du planning",
"Script Id"                => "Id du script",
"Script label"             => "Libell du script",
"Script language"          => "Langage de script",
"Script Name"              => "Nom du script",
"Script"                   => "Script",
"Scripts Id"               => "Id des scripts",
"Scripts Label"            => "Libell des scripts",
"scriptsl"                 => "Scripts et requetes",
"Scripts Name"             => "Noms des scripts",
"Scripts"                  => "Scripts",
"Scripts Status"           => "Etats des scripts",
"Script Status"            => "Etat du script",
"Script Text"              => "Text du script",
"Script Type"              => "Type du script",
"Search"                   => "Rechercher",
"Select Query"             => "Requete SELECT",
"Select"                   => "Selectionner",
"Sent Date"                => "Date d'envoie",
"Server Id"                => "Id du serveur",
"Server Label"             => "Libell du serveur",
"serverl"                  => "Serveurs",
"Server name"              => "Nom du serveur",
"Server"                   => "Serveur",
"Server status"            => "Etat du serveur",
"Seven Days"               => "7 jours",
"Show Errs"                => "Erreurs",
"Show fields"              => "Champs",
"Show Msgs"                => "Messages",
"Show"                     => "Voir",
"Simple"                   => "Simple",
"Six Days"                 => "Six jours",
"Skip"                     => "Skip",
"Slave connector"          => "Connecteur Alias",
"SMTP Connector Id"        => "Id du connecteur SMTP",
"Source Field"             => "Champ source",
"Special"                  => "Spcial",
"Sql scripts"              => "Scripts SQL",
"Sql"                      => "Sql",
"Stack Dump"               => "Contenu de la pile",
"Standard Dataformat"      => "Format standard des donnes",
"Standard Datatype"        => "Type standard des donnes",
"Status Date"              => "Etat  la Date",
"Status"                   => "Etat",
"Step"                     => "Etape",
"Stopped status"           => "Arrt",
"Stop"                     => "Stop",
"String"                   => "Chaine",
"Subflow dir"              => "Direction du sous-flux",
"Sub flow global transformation" => "Transformation global",
"Subflow Id"               => "Id du sous-flux",
"Sub Flow Id"              => "Id du sous-flux",
"Sub Flow label"           => "Libell du sous-flux",
"Subflow label"            => "Libell du sous-flux",
"Subflow method"           => "Mthode sous-flux",
"Subflow Name"             => "Nom du sous-flux",
"Sub Flow object"          => "Sous-flux",
"Sub Flows"                => "Sous-flux",
"Sub Flow status"          => "Etat du sous-flux",
"subflow"                  => "Definition des demi-flux",
"Sub Flow"                 => "Sous-flux",
"Sublow order"             => "Ordre",
"Sub Menu"                 => "SOUS MENU",
"Supported flows"          => "Types de flux suport",
"Support tansaction"       => "Transactions support",
"Support transaction"      => "Transactions support",
"System Pid"               => "Pid systme",
"Target field"             => "Champ destination",
"Three Days"               => "Trois jours",
"To Date"                  => "A",
"Top"                      => "Dbut",
"Trace File"               => "Ficher de trace (stdout)",
"Transform Date"           => "Date de transformation",
"Truncate Query"           => "Requete TRUNCATE",
"Try Later"                => "Essayer plus tard",
"Tuncate"                  => "Truncate",
"Two Days"                 => "Deux jours",
"Type"                     => "Type",
"Update Current Container" => "Mettre  jour le conteneur courant",
"Update Query"             => "Requte Update",
"Update"                   => "Update",
"Upd-Ins"                  => "Update puis Insert",
"Used For"                 => "Utilis pour",
"Use internal rollback space" => "Utiliser les espace de rollbacks cafeterra",
"User"                     => "Utilisateur",
"User Object"              => "Utilisateur",
"Cafeterra User Id"        => "Login",
"Connector User Id"        => "Id de l'utilisateur",
"Proxy User Id"            => "Id de l'utilisateur",
"User label"               => "Nom de l'utilisateur",
"user login"               => "Login",
"User Login"               => "Login de l'utilisateur",
"User Password"            => "Mot de passe",
"Users Id"                 => "Id Interne",
"Users Label"              => "Nom de l'utilisateur",
"Users Login"              => "Login de l'utilisateur",
"usersl"                   => "Utilisateurs",
"Users Name"               => "Nom ou Login de l'utilisateur",
"Users Password"           => "Mot de passe",
"Users Status"             => "Statut",
"User status"              => "Statut",
"User var"                 => "Variable pour les scripts",
"Variable ID"              => "Id de la variable",
"Variables"                => "Variables",
"Waited events"            => "Evnnement attendus",
"Wait Last?"               => "Attendre le dernier?",
"Wait last"                => "Attendre le dernier",
"Web Service"              => "Web service",
"Web Service Script"       => "Script pour Web Service",
"Web Serviec Object"       => "Flux de type webservice",
"Working dir"              => "Repertoire de travail",
"yes"                      => "Oui",
"Intro"                    => "<H1 aling=center>Bienvenue sur Cafeterra l'EAI LIBRE !</H1><P>", #"Introuction",
"Intro text"               => "
<XFONT SIZE=5><UL>
<LI>Configurez Cafeterra avec le menu <U>Configuration</U> (<U>Utilisateurs cafeterra</U>, <U>Contexts</U>)<BR>
<LI>Crez le dictionnaire des objets externes (<U>Utilisateurs</U>, <U>Serveurs</U>, <U>Connecteurs</U>, <U>Conteneurs</U>, <U>Champs</U>)
<LI>Crez Vos Flux et vos Scripts (<U>Menu Dfinition des flux</U>)
<LI>Dployez vos flux ainsi dfinis dans le contetxt de votre choix
<LI>Surveillez Vos Flux avec le menu <U>Surveillance</U>
</UL></font>",

"_addresse"                => "Address Edition",
"_addressl"                => "Addresses Listing",
"Adress Group"             => "",
"Adress Id"                => "0",
"Adress label"             => "0",
"Adress Label"             => "0",
"_attrdefe"                => "Edition des attributes",
"_attrdefl"                => "Liste des attributes",
"_cafusre"                 => "Edition des utilisateurs Cafeterra ",
"_cafusrl"                 => "Liste des utilisateurs Cafeterra",
"_connectore"              => "Edition des connecteurs",
"_connectorl"              => "Liste des connecteurs",
"_connectpage"             => "Connecxion CAFETERRA",
"_containere"              => "Edition des conteneurs",
"_containerl"              => "Liste des conteneurs",
"_contexte"                => "Edition des contextes",
"_contextl"                => "Liste des contextes",
"_dataformate"             => "Edition des Formats de donnes",
"dataformatl"              => "Formats des donnes",
"_dataformatl"             => "Liste des Formats de donnes",
"_datatypee"               => "Edition des types de donnes",
"_datatypel"               => "Liste des types de donnes",
"deleted"                  => "Supprime",
"Deploy "                  => "Dployer",
"Detail"                   => "Dtails",
"Doc Id"                   => "Id",
"_drivere"                 => "Edition des pilotes",
"_driverl"                 => "Liste des pilotes",
"Email Adress"             => "E-mail",
"_evente"                  => "Edition des vnements",
"_eventl"                  => "Liste des vnements",
"externalname"             => "Nom externe",
"Externalname"             => "Nom externe",
"_fielde"                  => "Edition des champs",
"_fieldl"                  => "Liste des champs",
"_menupage"                => "Page d'accueil",
"_merrore"                 => "Detail des Errurs d'un Flux",
"_merrorl"                 => "Surveillance des Erreurs de Flux",
"_mflowe"                  => "Suivie des erreurs de flux",
"_mflowl"                  => "Surveillance des flux",
"_mflowm"                  => "Suivie des messages",
"_mflowv"                  => "Surveillance des variables des flux",
"_mmsgd"                   => "Detail d'un Message",
"mmsgl"                    => "",
"_mmsgl"                   => "Suivie des Messages D'un flux",
"month_0"                  => "Janvier",
"month_10"                 => "Novembre",
"month_11"                 => "Decembre",
"month_1"                  => "Fevrier",
"month_2"                  => "Mars",
"month_3"                  => "Avril",
"month_4"                  => "Mai",
"month_5"                  => "Juin",
"month_6"                  => "Juillet",
"month_7"                  => "Aout",
"month_8"                  => "Sepetembre",
"month_9"                  => "Octobre",
"name"                     => "Nom",
"Name"                     => "Nom",
"_objectsl"                => "Listing de tous les objects",
"offline"                  => "Inactif",
"Oline status"             => "Actif",
"online"                   => "Actif",
"plscr"                    => "Scripts Perl",
"_protocole"               => "Edition des Protocols",
"_protocoll"               => "Liste des protocols",
"_proxycafe"               => "Edition des plannification",
"_proxycafl"               => "Liste des plannification",
"scale"                    => "Chiffres aprs la virgule",
"schedule"                 => "Calendrier",
"_schedulee"               => "Edition des planifications",
"_schedulel"               => "Liste des planifications",
"_scriptse"                => "Edition des scripts & requetes",
"_scriptsl"                => "Liste des scripts & requetes",
"scrqry"                   => "Scripts & Requetes",
"scrsched"                 => "Autres Planification",
"_servere"                 => "Edition des Serveurs",
"_serverl"                 => "Liste des serveurs",
"_install"                 => "CONFIGURATION D'UN CONTEXTE CAFETERRA",
"_sflowm"                  => "Demi-flux : Mapping des champs",
"_sflowe"                  => "Demi-flux : scripts et triggers",


"_flowl"                   => "Liste des flux",
"_sflowl"                  => "Liste des sous flux",
"_flowep"                  => "Flux scripts et triggers",
"_flowe"                   => "Edition du flux",
"_flowes"                  => "Demi-Flows",
"_import"                  => "Importer des objets Cafeterra",
"_export"                  => "Exporter des objets Cafeterra",
"_fieldt"                  => "Transformation  de champs",
"_lcontainer"              => "Importer la definition de Conteneurs",
"_lfield"                  => "Importer la dfinition de champs de conteneur",


"sqlscr"                   => "Requetes SQL",
"User Id"                  => "Login",
"_userse"                  => "Edition des utilisateurs externes",
"_usersl"                  => "Listes des utilisateurs externes",
"weekday_0"                => "Dimanche",
"weekday_1"                => "Lundi",
"weekday_2"                => "Mardi",
"weekday_3"                => "Mercredi",
"weekday_4"                => "Jeudi",
"weekday_5"                => "Vendredi",
"weekday_6"                => "Samedi",

"Addobjects"               => "Ajouter des lignes",
"export Append ObjectId"   => "Concatener l'id au nom de l'objet",
"export Blind Passwords"   => "Effacer les mots depasses",
"export Blind User Login"  => "Effacer les noms d'utilisateurs",
"Export Date"              => "Date d'exportation",
"export Host Names and Addresses" => "Effacer les adresses IP",
"Export"                   => "Exporter",
"exportobjects"            => "Exporter des objets",
"export Partner Id"        => "Id partenaire",
"export User Comment"      => "Commentaire",
"export User Comment"      => "Commentaire",
"Export Version"           => "Version Cafeterra",
"flowmethod"               => "Methode de flux",
"Force Import"             => "Forcer l'import",
"Import File Name"         => "Nom du fichier",
"importobjects"            => "Importer des objets",
"install"                  => "Configurer des contextes",
"Last Import Date"         => "Dernier Import",
"patchdb"                  => "Patcher la base de donnes",
"Select For Export"        => "Select",
"Select For Import"        => "Select",
"tools"                    => "Outils",




"alter"                    => "Requte Alter",
"create"                   => "Requte Create",
"ctransform"               => "Transformation d'un champ",
"delete"                   => "Requte Delete",
"drop"                     => "Requte drop",
"fafinish"                 => "Aprs fin flux",
"fastart"                  => "Aprs dbut flux",
"fbfinish"                 => "Avant fin du flux",
"fbstart"                  => "Avant dbut du flux",
"insert"                   => "Requte Insert",
"onerror"                  => "Gestion d'erreur",
"saconnect"                => "Aprs connexion",
"saopen"                   => "Aps prpare",
"saread"                   => "Aprs lecture enreg",
"satransf"                 => "Aprs transformation",
"sawrite"                  => "Aprs criture",
"sbconnect"                => "Avant connexion",
"sbopen"                   => "Avant Prepare",
"sbread"                   => "Avant Lecture",
"sbtransf"                 => "Avant transformation",
"sbwrite"                  => "Avant ecriture",
"select"                   => "Requte Select",
"stransform"               => "Transformation globale",
"truncate"                 => "Requte Truncate",
"update"                   => "Requte Update",
"user"                     => "Autres scripits",
"webservice"               => "Script Web Service",
"Continue"                 => "Continuer",
"Error date"               => "Date",
"FORCE DEPLOY"             => "Forcer la mise  jour",
"Generate an sql CREATE"   => "Gnrer une requte CREATE",
"Generate an sql DELETE"   => "Gnrer une requte DELETE",
"Generate an sql DROP"     => "Gnrer une requte DROP",
"Generate an sql INSERT"   => "Gnrer une requte INSERT",
"Generate an sql SELECT"   => "Gnrer une requte SELECT",
"Generate an sql TRUNCATE" => "Gnrer une requte TRUNCATE",
"Generate an sql UPDATE"   => "Gnrer une requte UPDATE",
"Generate an sql query"    => "Gnrer une requte SQL",
"Installed contexts"       => "Les contextes installs",
"Message types"            => "Types de message lcontainer.html",
"Set base directory"       => "Changer le rpertoire de base",


"rename"                   => "Requte Query",
"sbclose"                  => "Avant fermeture de la requte",
"saclose"                  => "Aprs fermeture de la requte",
"sbdiscon"                 => "Avant dconnexion du connecteur",
"sadiscon"                 => "Aprs dconnexion du connecteur",

);

 
# Object interface
 
sub new {
	bless {}, "cafetrans";
}
 
sub translate {
	$self = shift;
	$phrase = shift;
 
	if ($cafetrans::translation{$phrase}) { $cafetrans::translation{$phrase}; }
	else { $phrase; }
 
}

sub gethash {
        bless \%cafetrans::translation, "cafetrans";
}

1;
